import React from "react";
import { CodeTokenBuilder, CodeTokenProps, CodeTokenType } from "../types";
/**
 * `c063` 是一組語法高亮 token 建構器集合。
 * 每個 key 對應一種語法分類（如 `keyword1`, `string`, `comment` 等），
 * 回傳對應的 `CodeTokenProps` 物件。
 *
 * @example
 * ```tsx
 * const keyword = c063.keyword1("const");
 * const str = c063.string("'Hello'", { as: "code" });
 * ```
 *
 * @returns 以 `CodeTokenType` 為 key 的建構器函式集合。
 */
declare const c063: Record<CodeTokenType, CodeTokenBuilder>;
export default c063;
/**
 * 產生指定空白數量的 CodeToken，用於縮排、空格等用途。
 *
 * @param count 空白字元數，預設為 1
 * @returns type 為 `"default"`、內容為空格的 `CodeTokenProps`
 *
 * @example
 * ```tsx
 * tokens.push(whiteSpace(2)); // -> { type: "default", children: "  " }
 * ```
 */
export declare const whiteSpace: (count?: number) => CodeTokenProps<"span">;
/**
 * 抽取單個 `CodeTokenProps` 的純文字內容。
 *
 * @param token 要處理的 token
 * @returns 對應的文字內容
 *
 * @example
 * ```tsx
 * extractTokenContent(c063.keyword1("return")); // => "return"
 * ```
 */
export declare const extractTokenContent: <T extends React.ElementType>(token: CodeTokenProps<T>) => string;
/**
 * 判斷兩個 token 是否相等（type 與內容皆相同）。
 *
 * @param a 第一個 token
 * @param b 第二個 token
 * @returns 是否相等
 */
export declare const isTokenEqual: <T extends React.ElementType>(a: CodeTokenProps<T>, b: CodeTokenProps<T>) => boolean;
/**
 * 將 token 列表按語法類型分類。
 *
 * @param lines 二維陣列，每行為一組 token
 * @returns 分組後的 token 映射，key 為 `CodeTokenType`
 */
export declare const groupTokensByType: <T extends React.ElementType>(lines: CodeTokenProps<T>[][]) => Record<CodeTokenType, CodeTokenProps<T>[]>;
